#ifndef PINS_H
#define PINS_H
const char *PK_PINS[] = {
	/* future lastpass root CA (GlobalSign R1) */
	"K87oWBWM9UZfyddvDfoxL+8lpNyoUB2ptGtn0fv6G2Q=",
	/* future lastpass root CA (GlobalSign R2) */
	"iie1VXtL7HzAMF+/PVPR9xzT80kQxdZeJ+zduCB3uj0=",
	/* future lastpass root CA (GlobalSign R3) */
	"cGuxAXyFXFkWm61cF4HPWX8S0srS9j0aSqN0k4AP+4A=",
	/* current lastpass.com primary (leaf) */
	"YDjIAXSYj+mh+25FGifAiKN4oNOAj+as6gQv4naQG0M=",
	/* current lastpass.eu primary (leaf) */
	"SjMnNhjAyVM5Yv6O5JaQgNygBTU0wdb8Jz3mfQfTc28=",
	/* GlobalSign ECC OV SSL CA 2018 intermediate CA */
	"OD/WDbD3VsfMwwNzzy9MWd9JXppKB77Vb3ST2wn9meg="
};
#endif
